@@ -1,6 +1,23 @@
 #ifndef MTOOLS_NAMECLASH_H
 #define MTOOLS_NAMECLASH_H
 
+/*  Copyright 1996-1998,2000-2002,2008,2009 Alain Knaff.
+ *  This file is part of mtools.
+ *
+ *  Mtools is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Mtools is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "stream.h"
 
 typedef enum clash_action {
@@ -13,7 +30,7 @@ typedef enum clash_action {
 	NAMEMATCH_OVERWRITE,
 	NAMEMATCH_ERROR,
 	NAMEMATCH_SUCCESS,
-	NAMEMATCH_GREW,
+	NAMEMATCH_GREW
 } clash_action;
 
 /* clash handling structure */
@@ -34,12 +51,14 @@ typedef struct ClashHandling_t {
 	int source; /* to prevent the source from overwriting itself */
 	int source_entry; /* to account for the space freed up by the original 
 					   * name */
-	char * (*name_converter)(char *filename, int verbose, 
-				 int *mangled, char *ans);
+	void (*name_converter)(doscp_t *cp,
+			       const char *filename, int verbose, 
+			       int *mangled, dos_name_t *ans);
+	int is_label;
 } ClashHandling_t;
 
 /* write callback */
-typedef int (write_data_callback)(char *,char *, void *, struct direntry_t *);
+typedef int (write_data_callback)(dos_name_t *,char *, void *, struct direntry_t *);
 
 int mwrite_one(Stream_t *Dir,
 	       const char *argname,
